from autogen.client import FivetranClient


class Runner:
    def __init__(self, api_key, api_secret):
        self.client = FivetranClient(api_key, api_secret)

    def get_groups(self):
        all_groups = self.client.get_all_groups()
        groups = {}
        for group in all_groups["data"]["items"]:
            groups[group["name"]] = group["id"]
        return groups

    def get_connector_types(self, group_id):
        all_connectors = self.client.get_all_connectors_in_group(group_id)
        services = set()
        for connector in all_connectors["data"]["items"]:
            services.add(connector["service"])
        return list(services)

    def get_connectors(self, group_id, connector_type):
        all_connectors = self.client.get_all_connectors_in_group(group_id)
        connectors = {}
        for connector in all_connectors["data"]["items"]:
            if connector["service"] == connector_type:
                connectors[connector["schema"]] = connector["id"]
        return connectors



import yaml
from . import packages
try:
    import importlib.resources as pkg_resources
except ImportError:
    # Try backported to PY<37 `importlib_resources`.
    import importlib_resources as pkg_resources


class Config:
    def __init__(self, connector_selection):
        input = load_configuration(connector_selection)
        self.connector = connector_selection
        self.name = input["name"]
        self.version = input["version"]
        self.schema_variable = input["source_data_location"]["schema_variable"]
        self.database_variable = input["source_data_location"]["database_variable"]
        self.enabled_variables = input.get("enabled_variables", [])
        self.preset_variables = input.get("preset_variables", [])


def load_configuration(name: str):
    try:
        file = pkg_resources.read_text(packages, f"{name}.yml")
        configuration = yaml.load(file, Loader=yaml.FullLoader)
    except:
        raise Exception(f"Could not load configuration for {name}")

    return configuration



from pathlib import Path
from setuptools import setup, find_packages
from autogen import __version__

here = Path(__file__).parent.resolve()

with (here / "README.md").open(encoding="utf-8") as file:
    long_description = file.read()

setup(
    name="fivetran_autogen",
    version=__version__,
    py_modules=["fivetran_autogen"],
    packages=find_packages(),
    include_package_data=True,
    entry_points={"console_scripts": ["fivetran_autogen = autogen.cli:main"]},
    author="Fivetran",
    author_email="hello@fivetran.com",
    url="https://github.com/fivetran/dbt_autogen",
    install_requires=[
        "click",
        "ruamel.yaml",
        "PyYAML",
        "google-cloud-bigquery",
        "requests",
        "snowflake-sqlalchemy",
        "sqlalchemy",
    ],
    long_description=long_description,
    long_description_content_type="text/markdown",
)
